@@ -58,9 +58,9 @@ global error_count
 
 file_ignore_list = [
     # Ignore node module and rooms xml folders
-    "**\\node_modules\\**",
-    "**\\resources\\rooms\\**",
-    "**\\content\\rooms\\**",
+    "\\node_modules\\",
+    "\\resources\\rooms\\",
+    "\\content\\rooms\\",
     # Both of these files do not have a top-level tag, so they will always fail linting.
     # (The game's internal XML parser does not care about this.)
     "fxlayers.xml",
@@ -172,13 +172,17 @@ def main():
     global root_folder, expected_error_count, recursive, error_count
     total_error_count = 0
 
+    # Generalize root folder path
+    if not root_folder.endswith("**"):
+        if not root_folder.endswith("/") and not root_folder.endswith("\\"):
+            root_folder = root_folder + "\\"
+        root_folder = root_folder + "**"
+
     files = glob.glob(root_folder + "/**.xml", recursive=recursive)
+
     # remove files and folders to ignore
     for ignoreFile in file_ignore_list:
-        if not ignoreFile.startswith("*"):  # single file entry support
-            ignoreFile = "\\" + ignoreFile
-        ignoredFiles = glob.glob(root_folder + ignoreFile, recursive=True)
-        files = [f for f in files if f not in ignoredFiles]
+        files = [f for f in files if ignoreFile not in f]
 
     # if exists, remove all folders and files mentioned in the .gitignore file
     gitignore_files = get_gitignore_files()
@@ -300,7 +304,8 @@ def read_github_env_vars():
     printf("\tExpected Error Count: ", expected_error_count)
 
     if "INPUT_IGNORE" in os.environ:
-        file_ignore_list.extend(os.environ["INPUT_IGNORE"].split(","))
+        if not os.environ["INPUT_IGNORE"] == "":
+            file_ignore_list.extend(os.environ["INPUT_IGNORE"].split(","))
     printf("\tIgnored files: ", file_ignore_list)
 
 
